/*
 * Copyright 2024 cronn GmbH
 * SPDX-License-Identifier: AGPL-3.0-only
 */

package de.eshg.schoolentry.api;

import io.swagger.v3.oas.annotations.media.Schema;

@Schema(name = "SchoolEntryCountryCode", description = "Country codes by alpha-3 code (ISO 3166)")
public enum CountryCodeDto {
  AFG(5),
  EGY(8),
  ALB(2),
  ALG(8),
  AND(1),
  ANG(6),
  AUB(4),
  GNQ(6),
  ARA(8),
  ARG(4),
  ARM(5),
  ASE(5),
  ASN(5),
  ETH(6),
  AUS(3),
  BAM(4),
  BAH(8),
  BAL(2),
  BAD(5),
  BAR(4),
  BEL(1),
  BEZ(4),
  BEN(6),
  BHU(5),
  BOL(4),
  BOS(2),
  BOT(6),
  BRA(4),
  BRU(5),
  BUL(2),
  BUF(6),
  BUR(6),
  CHI(4),
  CHV(5),
  COO(3),
  COR(4),
  CIV(6),
  DAN(1),
  DEU(0),
  DOA(4),
  DOM(4),
  DSC(6),
  ECU(4),
  ELS(4),
  BRI(1),
  ERY(6),
  EST(2),
  FID(3),
  FIN(1),
  FRA(1),
  GAB(6),
  GAM(6),
  GEO(5),
  GHA(6),
  GOL(8),
  GRE(4),
  GRI(1),
  GUA(4),
  GUI(6),
  GUS(2),
  GUY(4),
  HAI(4),
  HND(4),
  IND(5),
  INS(5),
  IRQ(8),
  IRA(5),
  IRL(1),
  ISL(1),
  ISR(5),
  ITA(1),
  JAM(4),
  JAP(5),
  JEM(8),
  JOR(8),
  JUG(2),
  KAM(5),
  KAN(6),
  CAN(3),
  KAP(6),
  KAS(5),
  KAT(8),
  KEN(6),
  KIR(5),
  KIB(9),
  KOL(4),
  KOM(6),
  KON(6),
  KOR(5),
  KOS(2),
  KRO(2),
  KUB(4),
  KUW(8),
  LAO(5),
  LSO(6),
  LET(2),
  LEB(8),
  LIB(6),
  LYB(8),
  LIE(1),
  LIT(2),
  LUX(1),
  MAD(6),
  MAW(6),
  MAY(5),
  MAL(5),
  MAI(6),
  MLT(1),
  MAR(8),
  MHL(3),
  MAU(6),
  MAS(6),
  MAZ(2),
  MEX(4),
  MIK(3),
  MAM(4),
  MOL(2),
  MON(1),
  MOG(5),
  MNE(2),
  MOS(6),
  MYA(5),
  NAM(6),
  CHN(5),
  NAU(9),
  NEP(5),
  NEU(3),
  NIC(4),
  NED(1),
  NIG(6),
  NIA(6),
  NOK(5),
  NOR(1),
  OMA(8),
  OST(1),
  PAK(5),
  PAL(8),
  PAU(3),
  PAN(4),
  PAP(3),
  PAR(4),
  PER(4),
  PHI(5),
  POL(2),
  POR(1),
  RUA(6),
  RUM(2),
  RUS(2),
  SAL(3),
  SAB(6),
  SAA(3),
  SAN(1),
  STL(4),
  STP(6),
  SAU(8),
  SCO(1),
  SVE(1),
  HEL(1),
  SEN(6),
  SER(2),
  SEY(6),
  SIL(6),
  SIM(6),
  SIN(5),
  SKN(2),
  SLO(2),
  SOM(6),
  SON(9),
  SPA(1),
  CEY(5),
  STK(4),
  VCT(4),
  STA(9),
  SAR(6),
  SAM(4),
  SUD(6),
  SUK(5),
  SUR(4),
  SWA(6),
  SYR(8),
  TAD(5),
  TAI(5),
  TAN(6),
  THA(5),
  TIB(5),
  TIM(5),
  TOG(6),
  TRT(3),
  CHA(6),
  CZN(2),
  TUN(8),
  TUR(7),
  TKM(5),
  TUV(3),
  UGA(6),
  UKR(2),
  UUU(9),
  UNG(2),
  URU(4),
  USA(3),
  USB(5),
  VAN(3),
  VAT(1),
  VEN(4),
  VAE(8),
  VIE(5),
  WRU(2),
  SCA(6),
  ZYP(1),
  G1(1),
  G2(2),
  G3(3),
  G4(4),
  G5(5),
  G6(6),
  G7(7),
  G8(8),
  G9(9);

  private final Integer countryGroupCode;

  CountryCodeDto(Integer countryGroupCode) {
    this.countryGroupCode = countryGroupCode;
  }

  public Integer getCountryGroupCode() {
    return countryGroupCode;
  }

  public static CountryCodeDto getCountryGroup(int countryGroupCode) {
    return switch (countryGroupCode) {
      case 0 -> CountryCodeDto.DEU;
      case 1 -> CountryCodeDto.G1;
      case 2 -> CountryCodeDto.G2;
      case 3 -> CountryCodeDto.G3;
      case 4 -> CountryCodeDto.G4;
      case 5 -> CountryCodeDto.G5;
      case 6 -> CountryCodeDto.G6;
      case 7 -> CountryCodeDto.G7;
      case 8 -> CountryCodeDto.G8;
      case 9 -> CountryCodeDto.G9;
      default -> throw new IllegalStateException("Unexpected value: " + countryGroupCode);
    };
  }
}
